@@ -118,7 +118,7 @@ def cast(dtype: JAXDType, a: Union[Number, NPNumeric]):
 @dispatch
 def identity(a: Numeric):
     # Do not return `a` identically.
-    return 1 * a
+    return jnp.multiply(1, a)
 
 
 @dispatch
@@ -211,6 +211,11 @@ def arctanh(a: Numeric):
     return jnp.arctanh(a)
 
 
+@dispatch
+def loggamma(a: Numeric):
+    return jsps.gammaln(a)
+
+
 @dispatch
 def erf(a: Numeric):
     return jsps.erf(a)
@@ -377,4 +382,5 @@ def argsort(a: Numeric, axis: Int = -1, descending: bool = False):
 
 @dispatch
 def quantile(a: Numeric, q: Numeric, axis: Union[Int, None] = None):
+    q = B.cast(B.dtype_float(q), q)  # JAX requires this to be a float.
     return jnp.quantile(a, q, axis=axis, interpolation="linear")
