@@ -189,6 +189,11 @@ def arctanh(a: Numeric):
     return tf.atanh(a)
 
 
+@dispatch
+def loggamma(a: Numeric):
+    return tf.math.lgamma(a)
+
+
 @dispatch
 def erf(a: Numeric):
     return tf.math.erf(a)
